@@ -1,9 +1,10 @@
 from QuickProject.Commander import Commander
-from . import console, info_string
+from . import console, info_string, status
 from .Drawer import Drawer
+import os
 
-app = Commander("mtx-drawer", True)
-rt_path = "./"
+app = Commander("mtx-drawer")
+rt_path = os.path.abspath(os.getcwd())
 
 
 @app.command()
@@ -26,6 +27,7 @@ def draw_one(
     :return:
     """
     try:
+        status("处理").start()
         drawer = Drawer(
             filepath,
             "aver" in ops,
@@ -34,6 +36,7 @@ def draw_one(
             set_mat_size=mat_size,
             set_block_size=block_size,
         )
+        status.stop()
     except ValueError:
         return
     for func in ops:
@@ -57,18 +60,15 @@ def draw(
     :param block_size: 设置块大小（此参数设置后将覆盖mat_size）
     :return:
     """
-    import os
-
     has_aver = "aver" in ops
-    for rt, sonDirs, sonFiles in os.walk(rt_path, followlinks=True):
-        if not rt.endswith("/"):
-            rt += "/"
+    status("遍历并处理").start()
+    for rt, _, sonFiles in os.walk(rt_path, followlinks=True):
         for file in sonFiles:
             if file.endswith(".mtx"):
                 try:
-                    console.print(info_string, f'正在处理: "{rt + file}"')
+                    console.print(f'{os.path.join(rt, file)}', justify="center")
                     drawer = Drawer(
-                        rt + file,
+                        os.path.join(rt, file),
                         has_aver,
                         force,
                         log_times,
@@ -81,14 +81,25 @@ def draw(
                     continue
                 except Exception:
                     console.print_exception()
-                else:
-                    console.print(info_string, "处理完成")
                 finally:
                     console.print("-" * console.width)
+    status.stop()
     console.print(info_string, "处理完成")
     console.print("-" * console.width)
 
 
+@app.command()
+def update():
+    """
+    更新
+    """
+    from QuickProject import user_pip, external_exec
+
+    with status("正在更新..."):
+        external_exec(f"{user_pip} install -U MtxDrawer")
+    console.print(info_string, "更新完成")
+
+
 def main():
     app()
 
